/*
** Module   : tty.sockets.js
** Abstract : WebSockets communication management.
**
** Copyright (c) 2014, Golden Code Development Corporation.
** ALL RIGHTS RESERVED. Use is subject to license terms.
**
**         Golden Code Development Corporation
**                 CONFIDENTIAL
**
** -#- -I- --Date-- ----------------------Description--------------------------
** 001 MAG 20140110 First version.
*/

tty.socket = (function(screen, sound)
{
   /* exports object */
   var my = {}; 
   /* web socket */
   var ws;
   /* connected */
   var connected = false;

   /* send data */
   my.send = function(data)
   {
      if (connected) 
      {
         ws.send(data);
      }
   };
   
   /* initialize module */
   my.init = function(cfg)
   {      
      if ("WebSocket" in window)
      {
         ws = new WebSocket(cfg.url);

         ws.onopen = function()
         {
            connected=true;
            //alert("Connection is open...");
         };

         ws.onmessage = function(evt)
         {
            var pay = JSON.parse(evt.data);
            switch (pay.c)
            {
               case 0:
                  // clear screen 
                  screen.clear();                        
                  break;
               case 1:
                  // write to screen 
                  screen.type(pay.t);                        
                  break;
               case 2:
                  // set cursor position
                  screen.setCursorPosition(pay.x, pay.y);                        
                  break;
               case 3:
                  // show cursor
                  screen.setCursorStatus(true);                        
                  break;
               case 4:
                  // hide cursor
                  screen.setCursorStatus(false);                        
                  break;
               case 5:
                  // message beep
                  sound.beep();                        
                  break;
            };

            /*
            var text = '';
            var reader = new FileReader();
            reader.onloadend = function() 
            {
               text = reader.result; 
               screen.type(text);
            };
            reader.readAsText(evt.data);
            */              
         };

         ws.onclose = function()
         { 
            connected=false;
            // socket is closed.
            //alert("Connection is closed..."); 
         };
         
      } 
      else 
      {
         alert('WebSocket NOT supported by your Browser!');
      }      
   };
   
   /* exports */
   return my;       
}(tty.screen, tty.sound));
    
